@@ -13,24 +13,17 @@ SettingsDialog::SettingsDialog(QWidget *parent) : QDialog(parent)
   setModal(true);
   QFormLayout *layout = new QFormLayout(this);
 
-  names = new WidgetColorPicker();
-  days = new WidgetColorPicker();
-  weekends = new WidgetColorPicker();
-  weeks = new WidgetColorPicker();
-  cday = new WidgetColorPicker();
-  cdayback = new WidgetColorPicker();
+  names = new ColorButton(QColor(settings.value("color.names", "#FF0").toString()));
+  days = new ColorButton(QColor(settings.value("color.days", "#AAA").toString()));
+  weekends = new ColorButton(QColor(settings.value("color.weekends", "#F00").toString()));
+  weeks = new ColorButton(QColor(settings.value("color.weeks", "#00F").toString()));
+  cday = new ColorButton(QColor(settings.value("color.cday", "#000").toString()));
+  cdayback = new ColorButton(QColor(settings.value("color.cdayback", "#FF0").toString()));
 
   lang = new QComboBox();
   lang->addItem("System");
   lang->addItem("Russian");
 
-  names->setColor(QColor(settings.value("color.names", "#FF0").toString()));
-  days->setColor(QColor(settings.value("color.days", "#AAA").toString()));
-  weekends->setColor(QColor(settings.value("color.weekends", "#F00").toString()));
-  weeks->setColor(QColor(settings.value("color.weeks", "#00F").toString()));
-  cday->setColor(QColor(settings.value("color.cday", "#000").toString()));
-  cdayback->setColor(QColor(settings.value("color.cdayback", "#FF0").toString()));
-
   QString slang = settings.value("lang", "System").toString();
   for (int i = 0; i < lang->count(); i++)
     if (lang->itemText(i) == slang) lang->setCurrentIndex(i);
